@@ -1,13 +1,16 @@
 #!/bin/sh
 # Application Framework environment variable defines for all AF programs,
 # programs started by AF startup scripts and the D-BUS session bus.
-
-# Copyright (C) 2004-2006 Nokia Corporation.
+#
+# This file is part of osso-af-startup.
+#
+# Copyright (C) 2004-2006 Nokia Corporation. All rights reserved.
+#
+# Contact: Kimmo Hmlinen <kimmo.hamalainen@nokia.com>
 #
 # This program is free software; you can redistribute it and/or
-# modify it under the terms of the GNU General Public License as
-# published by the Free Software Foundation; either version 2 of the
-# License, or (at your option) any later version.
+# modify it under the terms of the GNU General Public License 
+# version 2 as published by the Free Software Foundation. 
 #
 # This program is distributed in the hope that it will be useful, but
 # WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -16,8 +19,8 @@
 #
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
-# USA
+# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
+# 02110-1301 USA
 
 # cancel 'set -e' because grep may return non-zero
 set +e
@@ -49,8 +52,10 @@ if [ "x$AF_DEFINES_SOURCED" = "x" ]; then
     mkdir $AF_PIDDIR
   fi
 
-  if [ "x$DISPLAY" = "x" ]; then
-    export DISPLAY=:0.0
+  if [ ! -e /targets/links/scratchbox.config ]; then
+    if [ "x$DISPLAY" = "x" ]; then
+      export DISPLAY=:0.0
+    fi
   fi
   export LAUNCHWRAPPER=$AF_INIT_DIR/launch-wrapper.sh
 
@@ -82,16 +87,22 @@ if [ "x$AF_DEFINES_SOURCED" = "x" ]; then
   if [ $? = 0 ]; then
     export INTERNAL_MMC_MOUNTPOINT='/media/mmc2'
     export INTERNAL_MMC_SWAP_LOCATION=$INTERNAL_MMC_MOUNTPOINT
+    export OSSO_SWAP=$INTERNAL_MMC_MOUNTPOINT
+
+    # enable UPnP/AV support
+    export UPNP_ROOT='upnpav://'
+
+    # enable multiple BT device support
+    export DISABLE_GATEWAY=1
+    export HILDON_FM_OBEX_ROOT='obex://'
+  else
+    export OSSO_SWAP=$MMC_MOUNTPOINT
   fi
   export ILLEGAL_FAT_CHARS=\\\/\:\*\?\<\>\| MAX_FILENAME_LENGTH=255
 
   # MMC swap file location (directory)
-  export OSSO_SWAP=$MMC_MOUNTPOINT
   export MMC_SWAP_LOCATION=$MMC_MOUNTPOINT
 
-  # this is for Control Panel
-  export User_Applets_Dir='/var/lib/install/usr/share/applications/hildon-control-panel/'
-
   source_if_is()
   {
     farg=$AF_INIT_DIR/$1 
