@@ -1,10 +1,14 @@
 #!/bin/sh
-# Copyright (C) 2004-2006 Nokia Corporation.
+#
+# This file is part of osso-af-startup.
+#
+# Copyright (C) 2004-2006 Nokia Corporation. All rights reserved.
+#
+# Contact: Kimmo Hmlinen <kimmo.hamalainen@nokia.com>
 #
 # This program is free software; you can redistribute it and/or
-# modify it under the terms of the GNU General Public License as
-# published by the Free Software Foundation; either version 2 of the
-# License, or (at your option) any later version.
+# modify it under the terms of the GNU General Public License 
+# version 2 as published by the Free Software Foundation. 
 #
 # This program is distributed in the hope that it will be useful, but
 # WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -13,28 +17,21 @@
 #
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
-# USA
+# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
+# 02110-1301 USA
 
 DIR=$AF_INIT_DIR
 
 if [ -x $DIR/osso-media-server.sh ]; then
   $DIR/osso-media-server.sh stop
 fi
-# this is first boot, so Connectivity UI is running
-if [ -x /usr/bin/osso-connectivity-ui.sh ]; then
-  source /usr/bin/osso-connectivity-ui.sh stop
-fi
-if [ -x $DIR/osso-connectivity-ui.sh ]; then
-  source $DIR/osso-connectivity-ui.sh stop
-fi
 # this is first boot, so VKB is running
 if [ -f $DIR/keyboard.defs ]; then
   source $DIR/keyboard.defs
 fi
 source $DIR/keyboard.sh stop
-source $DIR/dbus-sessionbus.sh stop
 sudo /etc/init.d/ke-recv stop
+source $DIR/dbus-sessionbus.sh stop
 
 # wait for the D-BUS session bus to die
 sleep 1
@@ -57,9 +54,6 @@ sudo /etc/init.d/osso-systemui restart
 if [ -x $DIR/osso-media-server.sh ]; then
   $DIR/osso-media-server.sh start &
 fi
-if [ -x /usr/bin/osso-connectivity-ui.sh ]; then
-  source /usr/bin/osso-connectivity-ui.sh start
-fi
 if [ -x $DIR/osso-connectivity-ui.sh ]; then
   source $DIR/osso-connectivity-ui.sh start
 fi
